@@ -114,6 +114,9 @@ class Workbook(object):
         else:
             return key in self.__sheetsByName
 
+    def __repr__(self):
+        return "Workbook(%s)" % self.filename
+
 class SharedStrings(list):
 
     def __init__(self, sharedStringsDom):
@@ -130,17 +133,16 @@ class Sheet(object):
         self.loaded = False
         self.addrPattern = re.compile("([a-zA-Z]*)(\d*)")
         self.__cells = {}
-        self.__cols = {}
-        self.__rows = {}
+        self.__cols = None
+        self.__rows = None
 
-    def __load(self):
+    def rowsIter(self):
         sheetDoc = self.workbook.domzip["xl/worksheets/sheet%d.xml" % self.id]
         sheetData = sheetDoc.find("{http://schemas.openxmlformats.org/spreadsheetml/2006/main}sheetData")
         # @type sheetData Element
-        rows = {}
-        columns = {}
         for rowNode in sheetData:
             rowNum = int(rowNode.get("r"))
+            rowCells = []
             for columnNode in rowNode:
                 colType = columnNode.get("t")
                 cellId = columnNode.get("r")
@@ -170,14 +172,22 @@ class Sheet(object):
                         formula = columnNode.find("{http://schemas.openxmlformats.org/spreadsheetml/2006/main}f").text
                 except Exception:
                     raise #pass
-                if not rowNum in rows:
-                    rows[rowNum] = []
+                cell = Cell(rowNum, colNum, data, formula=formula)
+                rowCells.append(cell)
+            yield rowNum, rowCells
+
+    def __load(self):
+        rows = {}
+        columns = {}
+        for rowNum, row in self.rowsIter():
+            rows[rowNum] = row
+
+            for cell in row:
+                colNum = cell.column
                 if not colNum in columns:
                     columns[colNum] = []
-                cell = Cell(rowNum, colNum, data, formula=formula)
-                rows[rowNum].append(cell)
+                self.__cells[cell.id] = cell
                 columns[colNum].append(cell)
-                self.__cells[cellId] = cell
         self.__rows = rows
         self.__cols = columns
         self.loaded=True
@@ -210,9 +220,16 @@ class Sheet(object):
             self.__load()
         return self.__cells.__iter__()
 
+<<<<<<< HEAD
+    def __repr__(self):
+        return "%r[%r]"%(self.workbook, self.name)
+
+class Cell(object):
+=======
 
 class Cell(UnicodeMixin):
 
+>>>>>>> 5fa8fa8761d3bfcb3ce1b1b730913f6d4d0ab0c9
     def __init__(self, row, column, value, formula=None):
         self.row = int(row)
         self.column = column
